ignored_html_tags = {
    "article",
    "aside",
    "blockquote",
    "body",
    "cite",
    "dialog",
    "figcaption",
    "figure",
    "footer",
    "frameset",
    "frame",  # TODO choper le contenu
    "header",
    "iframe",  # TODO choper le contenu
    "label",
    "main",
    "noframe",
    "noframes",
    "section",
    "show",
    "tbody",
    "transition",  # vue.js
    "time",
    "tt",
}
