removed_html_tags = {
    "apcomments",
    "audio",
    "button",
    "canvas",
    "form",
    "g:plusone",
    "g-popup",
    "hr",
    "input",
    "link",
    "meta",
    "nav",
    "noscript",
    "object",
    "script",
    "select",
    "source",
    "style",
    "svg",
    "video-js",
}
